"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _tryit = _interopRequireDefault(require("tryit"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const setupGlobalErrorHandlers = ({
  logger,
  extraDataGetter,
  extraCallback
}) => {
  const getExtraData = () => {
    if (!extraDataGetter) {
      return null;
    }

    try {
      return extraDataGetter();
    } catch (e) {
      return null;
    }
  };

  window.addEventListener('error', event => {
    const {
      message,
      filename,
      lineno,
      colno,
      error
    } = event;
    let errorObject = null;

    if (error) {
      errorObject = {
        message: error.message,
        stack: error.stack
      };
    }

    logger.error({
      message,
      filename,
      lineno,
      colno,
      errorObject,
      extraData: getExtraData()
    });
    extraCallback && (0, _tryit.default)(() => {
      extraCallback(event);
    });
  });
  window.addEventListener('unhandledrejection', event => {
    logger.error({
      message: 'unhandledRejection',
      event,
      reason: event.reason,
      extraData: getExtraData()
    });
    extraCallback && (0, _tryit.default)(() => {
      extraCallback(event);
    });
  });
};

var _default = setupGlobalErrorHandlers;
exports.default = _default;